==> igniteui-react-16.16.2.tgz: package/esm5/lib/NavDrawerItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var NavDrawerItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NavDrawerItem, _super);
    function NavDrawerItem() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(NavDrawerItem.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NavDrawerItem.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.a.d = this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NavDrawerItem.prototype, "d", {
        get: function () {
            var ret_ = this.b.c("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NavDrawerItem.prototype, "c", {
        get: function () {
            var ret_ = this.b.c("active");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("active", value_);
        },
        enumerable: false,
        configurable: true
    });
    NavDrawerItem.prototype.g = function () {
        this.nativeElement.connectedCallback();
    };
    NavDrawerItem.$t = markType(NavDrawerItem, 'NavDrawerItem', BaseElement.$);
    return NavDrawerItem;
}(BaseElement));
export { NavDrawerItem };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/NavDrawerItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var NavDrawerItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NavDrawerItem, _super);
    function NavDrawerItem() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(NavDrawerItem.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NavDrawerItem.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.a.o = this.e;
        },
        enumerable: false,
        configurable: true
    });
    NavDrawerItem.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(NavDrawerItem.prototype, "d", {
        get: function () {
            var ret_ = this.b.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NavDrawerItem.prototype, "c", {
        get: function () {
            var ret_ = this.b.n("active");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("active", value_);
        },
        enumerable: false,
        configurable: true
    });
    NavDrawerItem.prototype.g = function () {
        this.nativeElement.connectedCallback();
    };
    NavDrawerItem.$t = markType(NavDrawerItem, 'NavDrawerItem', BaseElement.$);
    return NavDrawerItem;
}(BaseElement));
export { NavDrawerItem };
